#!/bin/bash

##
## Installation script for server
##
## Author: Arthur Heffern
## Maintainer: Michael Yara
## Last Modified: Jan 6, 2014
##

# Setup variables for execution
SERVER_SCRIPT_NAME=`ls -1 *Server.sh | head -n 1`
NAME=`echo ${SERVER_SCRIPT_NAME} | sed s/.sh//`
LCNAME=`echo ${SERVER_SCRIPT_NAME} | tr '[A-Z]' '[a-z]' | sed s/server// | sed s/.sh//`
LOCATION="/opt/${LCNAME}3/server/";

# If config-vars.sh exists get the JRE path from that
if [ -e ${LOCATION}/config-vars.sh ]; then
    . ${LOCATION}/config-vars.sh
fi

# If no JAVA_HOME environment variable was found prompt the user for the path
if [ x${JAVA_HOME} = "x" ]; then
    echo "First, We need to know the path to your"
    echo "Sun / Oracle Java installation [/usr/java/latest]:"
    read JAVA_INSTALL_PATH
fi

# If the user provided no path default to "/usr/java/latest"
if [ x${JAVA_INSTALL_PATH} = "x" ]; then
    JAVA_HOME="/usr/java/latest"
else
    JAVA_HOME=${JAVA_INSTALL_PATH}
fi

# Check if a JRE could be found at the given path
echo "Checking for Java Binary ${JAVA_HOME}/bin/java.."
if [ ! -x ${JAVA_HOME}/bin/java ]; then
        echo "You do not appear to have the Sun Microsystems / Oracle Java Runtime"
        echo "Environment (JRE) installed.  We could not find the java binary"
    	echo "at:"
    	echo ""
    	echo "${JAVA_HOME}/bin/java"
        echo ""
        echo "This program will not function appropriately without JSE"
        echo "1.5 (Java 5) or greater."
        echo ""
    exit 1
fi

# Check if an installation directory already exists
echo "Checking For DESTDIR.."
if [ -e /opt/${LCNAME}3/server ]; then
    DESTDIR=/opt/${LCNAME}3/server
fi

# If an installation directory does not yet exits prompt the user for one.
# Default to "/opt/${LCNAME}3/server"
if [ x${DESTDIR} = "x" ]; then
    if [ x${INSTALLDIR} = "x" ]; then
        echo "Where would you like this package to be installed?"
        echo "[/opt/${LCNAME}3/server]"
        read INSTALL_PATH_INPUT
    fi

    if [ x${INSTALL_PATH_INPUT} = "x" ]; then
        DESTDIR="/opt/${LCNAME}3/server"
    else
        DESTDIR=${INSTALL_PATH_INPUT}
    fi
fi

echo "Configuration Complete, beginning install.."

# Check if we are running as the apropriate user to install
WHOAMI=`whoami`
if [ x${FREEPBX_RPM_BUILD} = "x" ] && [ ! -f /etc/freepbx.conf ] && [ ! -f /etc/amportal.conf ] ; then

    # Check if user is running as root
    if [ ${WHOAMI} != "root" ]; then
        echo "You must be root to install this application"
        exit 1
    fi

else

    # Check if user is running as root or asterisk
    if [ ${WHOAMI} != "root" ] && [ ${WHOAMI} != "asterisk" ] ; then
        echo "You must be root or asterisk to install this application"
        exit 1
    fi

fi

echo "Installing into ${DESTDIR}.."

# If an existing installation directory was not found create a new one
if [ ! -d ${DESTDIR} ]; then
    echo "Creating install directory.."
    if [ x${FREEPBX_RPM_BUILD} = "x" ] && [ ! -f /etc/freepbx.conf ] && [ ! -f /etc/amportal.conf ] ; then
    	echo "Installing as root"
    	install -d -v --group=root --owner=root ${DESTDIR}
    else
    	echo "Installing as asterisk"
    	install -d -v --group=asterisk --owner=asterisk ${DESTDIR}
    fi
fi

# If an existing installation was found upgrade the installation
if [ -e ${LOCATION}/${SERVER_SCRIPT_NAME} ]; then
    echo "Upgrade Installation Detected at ${LOCATION}.  Upgrading."
   
    # Remove all system modules   
    if [ -e ${LOCATION}/modules/framework ]; then
		rm -rf ${LOCATION}/modules/framework/
    fi
    
    if [ -e ${LOCATION}/modules/pbx ]; then
		rm -rf ${LOCATION}/modules/pbx/
    fi
    
    if [ -e ${LOCATION}/modules/freepbx ]; then
		rm -rf ${LOCATION}/modules/freepbx/
    fi
    
    if [ -e ${LOCATION}/modules/chat ]; then
		rm -rf ${LOCATION}/modules/chat/
    fi
    
    if [ -e ${LOCATION}/modules/asterisk ]; then
		rm -rf ${LOCATION}/modules/asterisk/
    fi
    
    if [ -e ${LOCATION}/modules/contact ]; then
		rm -rf ${LOCATION}/modules/contact/
    fi
    
    if [ -e ${LOCATION}/modules/lang-en-us ]; then
		rm -rf ${LOCATION}/modules/lang-en-us/
    fi
    
    if [ -e ${LOCATION}/modules/lang-ah ]; then
		rm -rf ${LOCATION}/modules/lang-ah/
    fi
    
    # Remove launcher
    if [ -e ${LOCATION}/launcher ]; then
		rm -rf ${LOCATION}/launcher
    fi
    
    # Remove war
    if [ -e ${LOCATION}/war ]; then
		rm -rf ${LOCATION}/war
    fi
   
    # Upgrade all non configuration and non log files
    for i in `find conf config-vars.sh jvm.args runtime.properties -type f`; do
        yes n | cp -ri $i ${DESTDIR}/${i}
    done
    
    for i in `ls -1 | grep -v config-vars.sh | grep -v "^conf$" | grep -v log | grep -v jvm.args | grep -v runtime.properties`; do
        cp -r ${i} ${DESTDIR}
    done;
    
    echo ""
    
# If no existing installation was found perform full install
elif [ -e ./${NAME}.jar ]; then
    for i in `ls -1`; do
        cp -r * ${DESTDIR}
    done
    echo "JAVA_HOME=${JAVA_HOME}" > ${DESTDIR}/config-vars.sh
fi

# Make the main server script executable
chmod uo+x ${DESTDIR}/*.sh
